@@ -3,7 +3,7 @@
 transformation codecs for use in data storage and communication
 applications. These include:
 
-* Compression codecs, e.g., Zlib, BZ2, LZMA and Blosc.
+* Compression codecs, e.g., Zlib, BZ2, LZMA, ZFPY and Blosc.
 * Pre-compression filters, e.g., Delta, Quantize, FixedScaleOffset,
   PackBits, Categorize.
 * Integrity checks, e.g., CRC32, Adler32.
@@ -16,7 +16,6 @@ contribute code, please `raise an issue on GitHub
 <https://github.com/alimanfoo/numcodecs/issues>`_.
 
 """
-
 import multiprocessing
 import atexit
 
@@ -68,6 +67,12 @@ try:
 except ImportError:  # pragma: no cover
     pass
 
+try:
+    from numcodecs.zfpy import ZFPY
+    register_codec(ZFPY)
+except ImportError:  # pragma: no cover
+    pass
+
 from numcodecs.astype import AsType
 register_codec(AsType)
 
@@ -92,6 +97,9 @@ register_codec(Pickle)
 from numcodecs.base64 import Base64
 register_codec(Base64)
 
+from numcodecs.shuffle import Shuffle
+register_codec(Shuffle)
+
 try:
     from numcodecs.msgpacks import MsgPack
     register_codec(MsgPack)
